import { RetryPolicy } from '../core.js';

type BackoffOptions = {
    /**
     * The base delay in milliseconds. This will be the delay for the first retry.
     * Subsequent retries will be exponentially longer. Defaults to 150ms.
     * @default 150
     */
    delay?: number | undefined;
    /**
     * The exponent to use for the exponential backoff. Using 1 will result in a
     * linear backoff. Defaults to 2.
     * @default 2
     */
    exp?: number | undefined;
    /**
     * The maximum delay in milliseconds. Once the delay reaches this value, it
     * will not increase any further. Defaults to 30 seconds.
     * @default 30000
     */
    max?: number | undefined;
};
/**
 * Use at the end of a chain of policies to generate an exponentially increasing
 * delay between retries.
 */
declare const Backoff: (options?: BackoffOptions) => RetryPolicy;

export { Backoff, type BackoffOptions };
