import { RetryPolicy } from '../core.js';

type LoggerOptions = {
    /**
     * A custom warn function to use instead of `console.warn`.
     * @default console.warn
     */
    warn?: typeof console.warn | undefined;
    /**
     * A custom error function to use instead of `console.error`.
     * @default console.error
     */
    error?: typeof console.error | undefined;
};
/**
 * Log retry attempts and operation failures. This policy should be used early
 * in the policy chain and will abort all operations if used at the end of the
 * chain.
 */
declare const Logger: (options?: LoggerOptions) => RetryPolicy;

export { Logger, type LoggerOptions };
